(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('underscore')) :
  typeof define === 'function' && define.amd ? define(['underscore'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, (global._ = global._ || {}, global._.mustache = factory(global._)));
}(this, (function (underscoreX_js) { 'use strict';

  var BLOCK, CLOSE, COMMENT, DYNAMIC, INVERTED, PARENT, PARTIAL, SECTION, SET_DELIMITER, UNESCAPED, VARIABLE, addIndentation, areDefault, argumentList, concat, conditionalTag, correctStandalone, decompile, defaultDelimiters, derefOp, detectClearance, escapeRegex, generateBlock, generateParent, _generateSection, initialIndent, interpolate, lineBreak, _mustache, newline, _parse, partial, payload, possiblyDynamic, pushNonEmptyLiteral, removeIndentation, renderInvertedSection, renderSection, renderSub, resolve, retokenize, section, sectionFunc, sectionList, sectionMismatch, spaces, specialChars, splitKey, strayEndingTag, stride, templateObject, tokenize, unclosedSection, variable;
  defaultDelimiters = ['{{', '}}'];
  newline = /\r?\n|\r/.source;
  spaces = /[ \t]*/.source; // Content of a tag. We capture all parts because we need to be able to
  // reconstruct the original template text.

  payload = /(?:(![^]*?)|(=\s*)([^=\s]+)(\s+)([^=\s]+)(\s*=)|(\{\s*)(.+?)(\s*\})|([&\#^\/><$]?)(\s*)(.+?)(\s*))/.source; // comment
  // set delimiter
  // unescaped variable with {{{}}}
  // regular key-based tags
  // Characters that must be escaped inside delimiters.

  specialChars = /[(){}[\]^$\.*+?\\|]/g; // Escaped version of a regular expression.

  escapeRegex = function escapeRegex(string) {
    return string.replace(specialChars, '\\$&');
  }; // Tokenization. Resulting stream always starts with a literal.


  tokenize = function tokenize(string, delimiters) {
    var close, open;
    open = escapeRegex(delimiters[0]);
    close = escapeRegex(delimiters[1]);
    return string.split(new RegExp("(".concat(newline, ")?(").concat(spaces, ")(").concat(open, ")").concat(payload, "(").concat(close, ")(").concat(spaces, "(?:").concat(newline, "))?")));
  }; // Total number of capturing groups per tag, plus one for the literal in between.


  stride = 19; // Safe concatenation for compile-time, when captured tokens might be undefined.

  concat = function concat(stream, start, end) {
    var t;
    return function () {
      var i, len, ref, results;
      ref = stream.slice(start, end);
      results = [];

      for (i = 0, len = ref.length; i < len; i++) {
        t = ref[i];

        if (t) {
          results.push(t);
        }
      }

      return results;
    }().join('');
  }; // Re-tokenize the trailing part of a previously tokenized stream, using the new
  // delimiters.


  retokenize = function retokenize(stream, position, delimiters) {
    var retokenized, trailing;
    trailing = concat(stream, position);
    retokenized = tokenize(trailing, delimiters);
    return stream.splice.apply(stream, [position, stream.length].concat(retokenized));
  }; // Compare a pair of delimiters to the default.


  areDefault = function areDefault(delim) {
    return delim[0] === defaultDelimiters[0] && delim[1] === defaultDelimiters[1];
  }; // Parsing
  // -------
  // Turning a flat sequence of constituents into a hierarchy. This stage is purely
  // syntactical; we focus exclusively on collecting enough information to identify
  // which tags belong together and whether they are standalone or not. The literal
  // text between the tags is left implicit.
  // Mnemonics for tag types. Reusing sigils for code economy.


  VARIABLE = '';
  UNESCAPED = '&';
  SECTION = '#';
  INVERTED = '^';
  CLOSE = '/';
  PARTIAL = '>';
  PARENT = '<';
  BLOCK = '$';
  COMMENT = '!';
  SET_DELIMITER = '='; // Determine whether a tag is cleared by a line end on either side.

  detectClearance = function detectClearance(stream, oldPosition, position, slice) {
    var clearLeft, clearRight, prepost;
    prepost = stream[oldPosition - 1] ? true : oldPosition === 0;
    clearLeft = slice[1] != null || slice[0] === '' && prepost;
    clearRight = slice[18] != null || position + 1 === stream.length && slice[19] === '';
    return {
      clearLeft: clearLeft,
      clearRight: clearRight
    };
  }; // Nesting errors encountered during parsing.


  strayEndingTag = function strayEndingTag(stream, tag) {
    throw SyntaxError("Stray section end: ".concat(concat(stream, tag.start, tag.end)));
  };

  sectionMismatch = function sectionMismatch(stream, open, close) {
    var begin, end;
    begin = concat(stream, open.start, open.end);
    end = concat(stream, close.start, close.end);
    throw SyntaxError("Nonmatching keys at begin and end of section: ".concat(begin, "...").concat(end));
  };

  unclosedSection = function unclosedSection(stream, tag) {
    throw SyntaxError("No matching section end found before end of template: ".concat(concat(stream, tag.start, tag.end)));
  }; // Core parsing algorithm. Recurses into sections, parents and blocks.


  _parse = function parse(stream, position, delimiters, inParent) {
    var altKey, close, closingTag, key, nested, oldPosition, open, sigil, slice, tagInfo, tags, type;
    tags = [];

    while (true) {
      oldPosition = position;
      position += stride;

      if (position > stream.length) {
        break;
      } // [,, indent,,,, open,, close,,, altKey,, sigil,, key,,,,]


      slice = stream.slice(oldPosition, position + 1);
      sigil = slice[13];
      altKey = slice[11]; // For every tag in the template, we collect basic information such as
      // its `key` and `type`, its boundaries and the `delimiters` that were in
      // effect immediately *before* the tag.

      tagInfo = detectClearance(stream, oldPosition, position, slice);
      tagInfo.start = oldPosition + 3;
      tagInfo.end = position - 1;
      tagInfo.key = key = altKey || slice[15];
      tagInfo.delimiters = delimiters;
      tagInfo.type = type = altKey ? UNESCAPED : key ? sigil : (open = slice[6]) ? (close = slice[8], open !== delimiters[0] || close !== delimiters[1] ? (delimiters = [open, close], retokenize(stream, position, delimiters)) : void 0, SET_DELIMITER) : COMMENT;

      if (type === CLOSE) {
        // End a recursive call.
        closingTag = tagInfo;
        break;
      }

      if (inParent && type !== BLOCK) {
        continue;
      }

      tags.push(function () {
        switch (type) {
          case SECTION:
          case INVERTED:
          case PARENT:
          case BLOCK:
            // Start a recursive call.
            nested = _parse(stream, position, delimiters, type === PARENT);
            var _nested = nested;
            position = _nested.position;
            delimiters = _nested.delimiters;
            close = _nested.closingTag;

            if (!close) {
              unclosedSection(stream, tagInfo);
            }

            if (close.key !== tagInfo.key) {
              sectionMismatch(stream, tagInfo, close);
            }

            return {
              // The object that we represent a subtree with is somewhat
              // similar to a `tagInfo`: both have a `key` and a `type`. The
              // difference is that the boundaries are represented through the
              // `open` and `close` properties and that it contains an array of
              // nested `tags`.
              type: type,
              key: key,
              open: tagInfo,
              close: close,
              tags: nested.tags
            };

          default:
            return tagInfo;
        }
      }());
    }

    return {
      delimiters: delimiters,
      position: position,
      tags: tags,
      closingTag: closingTag
    };
  }; // Runtime support functions
  // -------------------------
  // These will be used inside the generated functions. Where the parsing section
  // expressed the syntax of the template language, the current section expresses
  // its semantics.
  // Use the section function to "render" the original template text.


  decompile = function decompile(state, sectionFunc) {
    var text;
    state.d = true;
    text = sectionFunc(state);
    state.d = false;
    return text;
  }; // Resolve a name in the context, following the algorithm from the spec.


  resolve = function resolve(state, keys, sectionFunc) {
    var end, frame, frameIndex, i, key, keyIndex, size, stack, value;
    keyIndex = 0;
    key = keys[keyIndex];
    size = keys.length;
    stack = state.context;
    end = stack.length - 1;

    if (size) {
      for (frameIndex = i = end; i >= 0; frameIndex = i += -1) {
        frame = stack[frameIndex];

        if (frame != null && (value = frame[key]) !== void 0) {
          break;
        }
      }

      if (value === void 0) {
        frame = void 0;
      }
    } else {
      frame = stack[end - 1];
      value = stack[end];
    }

    while (frame != null && ++keyIndex < size) {
      frame = underscoreX_js.isFunction(value) ? sectionFunc ? (sectionFunc.sectionText != null ? sectionFunc.sectionText : sectionFunc.sectionText = decompile(state, sectionFunc), value.call(frame, sectionFunc.sectionText)) : value.call(frame) : value;
      value = frame != null ? frame[keys[keyIndex]] : void 0;
    }

    return {
      frame: frame,
      value: value
    };
  }; // Substitute a `{{variable}}`, `{{{variable}}}` or `{{&variable}}`.


  interpolate = function interpolate(state, key) {
    var safe = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
    var frame, value;

    var _resolve = resolve(state, key);

    frame = _resolve.frame;
    value = _resolve.value;

    if (underscoreX_js.isFunction(value)) {
      if (underscoreX_js.isString(value = value.call(frame))) {
        value = _mustache(value)(null, state);
      }
    }

    if (safe) {
      return underscoreX_js.escape(value);
    } else {
      return String(value != null ? value : '');
    }
  }; // Render a `{{#section}}...{{/section}}` zero or more times.


  renderSection = function renderSection(state, key, func, delimiters) {
    var context, frame, i, item, len, repeats, sectionText, value;
    func = state.sections[func];

    if (state.d) {
      return func(state);
    }

    var _resolve2 = resolve(state, key, func);

    frame = _resolve2.frame;
    value = _resolve2.value;

    if (!value) {
      return '';
    }

    if (underscoreX_js.isFunction(value)) {
      sectionText = func.sectionText != null ? func.sectionText : func.sectionText = decompile(state, func);
      value = value.call(frame, sectionText);

      if (value === sectionText) {
        return func(state);
      }

      if (underscoreX_js.isString(value)) {
        return _mustache(value, delimiters)(null, state);
      }
    }

    if (underscoreX_js.isString(value) || !underscoreX_js.isNumber(value.length)) {
      value = [value];
    }

    repeats = '';
    context = state.context;

    for (i = 0, len = value.length; i < len; i++) {
      item = value[i];
      context.push(item);
      repeats += func(state);
      context.pop();
    }

    return repeats;
  }; // Render a `{{^section}}...{{/section}}` zero or one times.


  renderInvertedSection = function renderInvertedSection(state, key, func) {
    var value;
    func = state.sections[func];

    if (state.d) {
      return func(state);
    }

    var _resolve3 = resolve(state, key, func);

    value = _resolve3.value;

    switch (false) {
      case !!value:
        return func(state);

      case !underscoreX_js.isFunction(value):
        return '';

      case value.length !== 0:
        return func(state);

      default:
        return '';
    }
  }; // Indent a block of text.


  lineBreak = /^(?!$)/mg;

  addIndentation = function addIndentation(text, indent) {
    return text.replace(lineBreak, indent);
  }; // Render a `{{>partial}}`, `{{<parent}}` or `{{$block}}`, precompiling and
  // indenting as needed.


  renderSub = function renderSub(state, name, control, indent) {
    var blocks, index, key, options, partials, reindented, sections, template, text;
    partials = state.partials;
    blocks = state.blocks;
    sections = state.sections;

    if (underscoreX_js.isNumber(control)) {
      // Numeric index of a block.
      template = !state.d && blocks[name] || sections[control];
      control = blocks;
    } else {
      // Partial or parent.
      if (underscoreX_js.isArray(name)) {
        // Dynamic partial.
        name = interpolate(state, name, false);
      }

      template = partials[name];

      if (underscoreX_js.isString(template)) {
        text = template;
        partials[name] = template = _mustache(template);
        template.templateText = text;
      }

      if (!underscoreX_js.isFunction(template)) {
        return '';
      }

      if (underscoreX_js.isObject(control)) {
        for (key in control) {
          index = control[key]; // Parent.

          control[key] = sections[index];
        }

        for (key in blocks) {
          control[key] = blocks[key];
        }
      } else {
        // Plain partial, static or dynamic.
        indent = control;
        control = {};
      }
    }

    options = {
      context: state.context,
      partials: partials,
      blocks: control
    };

    if (indent) {
      reindented = template.reindented != null ? template.reindented : template.reindented = {};

      if (reindented[indent]) {
        template = reindented[indent];
      } else {
        if (text == null) {
          text = template.templateText != null ? template.templateText : template.templateText = template(null, {
            decompile: true
          });
        }

        text = addIndentation(text, indent);
        template = reindented[indent] = _mustache(text, template.delimiters);
        template.templateText = text;
      }
    }

    if (state.d) {
      return text != null ? text : template.templateText != null ? template.templateText : template.templateText = template(null, {
        decompile: true
      });
    } else {
      return template(null, options);
    }
  }; // Code generation
  // ---------------
  // Where new JavaScript functions are born.
  // Compiled representation of a (dotted) name or implicit iterator.


  splitKey = function splitKey(key) {
    if (key === '.') {
      return '[]';
    } else {
      return JSON.stringify(key.split('.'));
    }
  }; // Argument list for a function call, from a list of compiled expressions.


  argumentList = function argumentList(args) {
    return "(state, ".concat(args.join(', '), ")");
  }; // Expressions representing each of the main constituents of a Mustache template.
  // We compose larger string concatenation expressions out of these.
  // Literal parts are simply represented as themselves using `JSON.stringify`.


  variable = function variable(args) {
    return "state.v".concat(argumentList(args));
  };

  section = function section(type, args, delimiters) {
    if (!areDefault(delimiters)) {
      args.push(JSON.stringify(delimiters));
    }

    return "state.".concat(type === SECTION ? 's' : 'z').concat(argumentList(args));
  };

  partial = function partial(args) {
    return "state.p".concat(argumentList(args));
  }; // In decompile mode, tags should render as themselves instead of as whatever
  // their semantics dictate.


  conditionalTag = function conditionalTag(decompiling) {
    var compiling = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '""';
    return "(state.d ? ".concat(JSON.stringify(decompiling), " : ").concat(compiling, ")");
  }; // Each section gets its own function with a string concatenation expression.


  sectionFunc = function sectionFunc(terms) {
    return "function(state) {\n    return ".concat(terms.join(' + ') || '""', ";\n}");
  }; // Array of section functions.


  sectionList = function sectionList(funcs) {
    return "[".concat(funcs.join(', '), "]");
  }; // Full description of both whole templates and nested blocks.


  templateObject = function templateObject(sectionList, delimiters) {
    var parts;
    parts = ["sections: ".concat(sectionList)];

    if (!areDefault(delimiters)) {
      parts.push("delimiters: ".concat(JSON.stringify(delimiters)));
    }

    return "{".concat(parts.join(', '), "}");
  }; // Literal parts of the template are copied verbatim, but for efficiency, we only
  // do this when not empty.


  pushNonEmptyLiteral = function pushNonEmptyLiteral(stream, start, end, terms) {
    var literalFragment;

    if (literalFragment = concat(stream, start, end)) {
      return terms.push(JSON.stringify(literalFragment));
    }
  }; // If a tag clears on both sides, consider leading indentation and trailing
  // spaces and line end part of the tag text in order to prevent spurious
  // whitespace in the output. We allow passing a second argument so that clearing
  // and position information about the left and right sides can be obtained from
  // different tags.


  correctStandalone = function correctStandalone(leftTag) {
    var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : leftTag,
        end = _ref.end,
        clearRight = _ref.clearRight;

    var clearLeft, isStandalone, start;
    start = leftTag.start;
    clearLeft = leftTag.clearLeft;
    isStandalone = clearLeft && clearRight;
    start -= +isStandalone;
    end += +isStandalone;
    return {
      start: start,
      end: end,
      isStandalone: isStandalone
    };
  }; // Mnemonic for the character that starts dynamic names, and a regular
  // expression for taking it off, together with following whitespace.


  DYNAMIC = '*';
  derefOp = /^\*\s*/; // In partials and parents, the name may be prefixed with a star to indicate that
  // the name should be dynamically resolved from the context. In that case, the
  // star is removed and the remainder of the name is split on the dots, like in
  // variables and sections. Otherwise, we encode the name as a single string.

  possiblyDynamic = function possiblyDynamic(key) {
    if (key[0] === DYNAMIC) {
      return splitKey(key.replace(derefOp, ''));
    } else {
      return JSON.stringify(key);
    }
  }; // Generate code for the content within a section of the template, pushing one or
  // more function source strings to `sections`. This is also the entry point for
  // the template as a whole. Returns the index of the top-level generated section.


  _generateSection = function generateSection(stream, previousEnd, nextStart, _ref2, sections) {
    var tags = _ref2.tags;
    var args, blockInfo, close, delimiters, end, i, iEnd, iStart, indent, isStandalone, key, len, open, renderTerm, serial, start, tagFragment, term, terms, tree, type;
    terms = [];

    for (i = 0, len = tags.length; i < len; i++) {
      tree = tags[i];
      term = renderTerm = void 0;
      var _tree = tree;
      type = _tree.type;
      key = _tree.key;
      start = _tree.start;
      end = _tree.end;
      open = _tree.open;
      close = _tree.close;

      if (type === PARENT || type === BLOCK) {
        var _correctStandalone = correctStandalone(open, close);

        start = _correctStandalone.start;
        end = _correctStandalone.end;
        isStandalone = _correctStandalone.isStandalone;
        indent = isStandalone && stream[start];
      }

      switch (type) {
        case VARIABLE:
        case UNESCAPED:
          args = [splitKey(key)];

          if (type === UNESCAPED) {
            args.push(0);
          }

          renderTerm = variable(args);
          break;

        case SECTION:
        case INVERTED:
          var _correctStandalone2 = correctStandalone(open);

          start = _correctStandalone2.start;
          iEnd = _correctStandalone2.end;

          var _correctStandalone3 = correctStandalone(close);

          iStart = _correctStandalone3.start;
          end = _correctStandalone3.end;
          serial = _generateSection(stream, iEnd, iStart, tree, sections);
          var _open = open;
          delimiters = _open.delimiters;
          renderTerm = section(type, [splitKey(key), serial], delimiters);
          break;

        case PARTIAL:
          var _correctStandalone4 = correctStandalone(tree);

          start = _correctStandalone4.start;
          end = _correctStandalone4.end;
          isStandalone = _correctStandalone4.isStandalone;
          args = [possiblyDynamic(key)];

          if (isStandalone) {
            args.push(JSON.stringify(stream[start]));
          }

          renderTerm = partial(args);
          break;

        case PARENT:
          term = generateParent(stream, start, end, tree, sections, indent);
          break;

        case BLOCK:
          if (isStandalone && !close.clearLeft) {
            --end;
          }

          blockInfo = generateBlock(stream, tree, sections, indent);
          var _blockInfo = blockInfo;
          iEnd = _blockInfo.iEnd;
          iStart = _blockInfo.iStart;
          renderTerm = _blockInfo.renderTerm;
          break;

        default:
          var _correctStandalone5 = correctStandalone(tree);

          start = _correctStandalone5.start;
          end = _correctStandalone5.end;
      }

      if (type === SECTION || type === INVERTED || type === BLOCK) {
        term = [conditionalTag(concat(stream, start, iEnd)), renderTerm, conditionalTag(concat(stream, iStart, end))].join(' + ');
      }

      pushNonEmptyLiteral(stream, previousEnd, start, terms);

      if (!term) {
        tagFragment = concat(stream, start, end);
        term = conditionalTag(tagFragment, renderTerm);
      }

      terms.push(term);
      previousEnd = end;
    }

    pushNonEmptyLiteral(stream, previousEnd, nextStart, terms);
    return sections.push(sectionFunc(terms)) - 1;
  }; // Within `{{<parent}}...{{/parent}}` tags, all text outside of blocks is
  // considered a comment. Whitespace is handled quite differently as a result.


  generateParent = function generateParent(stream, start, end, tree, sections, indent) {
    var args, blockInfo, blocks, i, len, ref, subtree, terms;
    terms = [];
    blocks = {};
    ref = tree.tags;

    for (i = 0, len = ref.length; i < len; i++) {
      subtree = ref[i];
      blockInfo = generateBlock(stream, subtree, sections);
      blocks[subtree.key] = blockInfo.serial;
      pushNonEmptyLiteral(stream, start, blockInfo.iEnd, terms);
      terms.push(blockInfo.renderTerm);
      start = blockInfo.iStart;
    }

    pushNonEmptyLiteral(stream, start, end, terms);
    args = [possiblyDynamic(tree.key), JSON.stringify(blocks)];

    if (indent) {
      args.push(JSON.stringify(indent));
    }

    return "(state.d ? ".concat(terms.join(' + '), " : state.p").concat(argumentList(args), ")");
  }; // Remove intrinsic indentation from a block. We re-tokenize and re-parse the
  // stream, because doing this correctly is otherwise extremely complicated.


  initialIndent = new RegExp("^".concat(spaces));

  removeIndentation = function removeIndentation(stream, _ref3) {
    var open = _ref3.open,
        close = _ref3.close;
    var chunks, dedentPattern, end, indent, start, text;
    start = open.end + 1;
    end = close.start - 2;
    text = concat(stream, start, end);
    indent = initialIndent.exec(text)[0];

    if (!indent) {
      return indent;
    }

    dedentPattern = new RegExp("^".concat(indent), 'mg');
    chunks = tokenize(text.replace(dedentPattern, ''), open.delimiters);

    _parse(chunks, 0, open.delimiters);

    stream.splice.apply(stream, [start, end - start].concat(chunks));
    return indent;
  }; // A block behaves like a partial that is embedded within the larger template and
  // that can be exchanged with other templates. For this reason, most of the code
  // generation happens inside a recursive call to generateSection.


  generateBlock = function generateBlock(stream, tree, sections, indent) {
    var args, close, iEnd, iStart, nonempty, open, renderTerm, serial, subSections;
    open = tree.open;
    close = tree.close;
    iEnd = open.end;
    iStart = close.start;
    nonempty = iStart - iEnd > 4 || stream[iEnd + 1];

    if (indent !== false && open.clearRight && nonempty) {
      // Intrinsic indentation of the content between the block tags takes
      // precedence over any indentation that might be in front of the open
      // tag. This is done at code generation time because we need to make a
      // preorder traversal of nested blocks.
      indent = removeIndentation(stream, tree);
      iEnd += 1;
      iStart -= close.clearLeft;
    }

    subSections = [];

    _generateSection(stream, iEnd, iStart, tree, subSections);

    serial = sections.length;
    sections.push(templateObject(sectionList(subSections), open.delimiters));
    args = [JSON.stringify(tree.key), serial];

    if (indent) {
      args.push(JSON.stringify(indent));
    }

    renderTerm = partial(args);
    return {
      serial: serial,
      renderTerm: renderTerm,
      indent: indent,
      iEnd: iEnd,
      iStart: iStart
    };
  }; // Wrapping up
  // -----------
  // We compose our final interface from the parts above.
  // The function this is all about, and which we will export.
  // One stop solution for compiling and wrapping templates.


  _mustache = function mustache(source) {
    var delimiters = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultDelimiters;
    var element, i, index, len, sectionText, sections, stream, template, topLevel, tree; // Compile the template text if this hasn't been done yet.

    if (underscoreX_js.isString(source)) {
      stream = tokenize(source, delimiters);
      tree = _parse(stream, 0, delimiters);

      if (tree.closingTag) {
        strayEndingTag(stream, tree);
      }

      sections = [];

      _generateSection(stream, 0, stream.length, tree, sections);

      sectionText = sectionList(sections);
      sections = new Function("return ".concat(sectionText))();
    } else {
      sections = source.sections;
      delimiters = source.delimiters;

      if (delimiters == null) {
        delimiters = defaultDelimiters;
      }
    }

    if (!underscoreX_js.isArray(sections)) {
      throw new TypeError("Expected template string or precompiled template representation, got ".concat(source));
    } // Recurse into any nested blocks if present.


    for (index = i = 0, len = sections.length; i < len; index = ++i) {
      element = sections[index];

      if (!underscoreX_js.isFunction(element)) {
        sections[index] = _mustache(element);
      }
    } // Create the final template function out of the compiled section functions.
    // Fun fact: this is the only closure in the whole setup.


    topLevel = sections.pop();

    template = function template(data) {
      var _ref4 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
          context = _ref4.context,
          partials = _ref4.partials,
          blocks = _ref4.blocks,
          decompile = _ref4.decompile;

      return topLevel({
        context: context || [data],
        sections: sections,
        partials: partials || _mustache.partials,
        blocks: blocks || {},
        d: decompile,
        v: interpolate,
        s: renderSection,
        z: renderInvertedSection,
        p: renderSub
      });
    };

    template.delimiters = delimiters;

    if (sectionText) {
      template.source = templateObject(sectionText, delimiters);
    }

    return template;
  };

  _mustache.partials = {};
  var _mustache$1 = _mustache;

  return _mustache$1;

})));
//# sourceMappingURL=mustache-umd.js.map
