'use strict';

var mustache = require('.');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var mustache__default = /*#__PURE__*/_interopDefaultLegacy(mustache);

var AMD, CommonJS, ESM, partials, render, templateExpression, wrapModule;

templateExpression = "{{&wontache}}({{&template}}{{#delimiters}}{{^precompile}}, {{&.}}{{/precompile}}{{/delimiters}})"; // Mustache expression wrapped as the only (default) export of a module, in three
// different module conventions.

ESM = "import {{&wontache}} from 'wontache';\nexport default {{>templateExpression}};";
AMD = "define(['wontache'], function({{&wontache}}) {\n    return {{>templateExpression}};\n});";
CommonJS = "var {{&wontache}} = require('wontache');\nmodule.exports = {{>templateExpression}};"; // We wrap templates as modules using the above templates, so we need the latter
// available as partials.

partials = {
  templateExpression: templateExpression,
  ESM: ESM,
  AMD: AMD,
  CommonJS: CommonJS
}; // All of the above consolidated in a single template, that dynamically selects
// the apropriate partial based on the module type.

render = mustache__default['default']('{{>*type}}\n'); // Given a string of Mustache `template` code and some options, return a string
// of JavaScript code. The JavaScript code represents a complete module with a
// single (default) export, being the compiled `template`. If `precompile` is
// `true`, `template` compilation happens during the invocation of `wrapModule`,
// saving startup time in the generated JavaScript module; otherwise, compilation
// is postponed until the generated module is evaluated, saving code size. The
// `type` defaults to `'ESM'`, but can also be set to `'AMD'` or `'CommonJS'`.
// `wontache` can be overridden to set an alternative name for the compiler as it
// is imported from the Wontache package.

wrapModule = function wrapModule(template) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      precompile = _ref.precompile,
      type = _ref.type,
      delimiters = _ref.delimiters,
      wontache = _ref.wontache;

  template = precompile ? mustache__default['default'](template, delimiters).source : JSON.stringify(template);

  if (delimiters) {
    delimiters = JSON.stringify(delimiters);
  }

  if (type == null) {
    type = 'ESM';
  }

  if (wontache == null) {
    wontache = 'mustache';
  }

  return render({
    template: template,
    precompile: precompile,
    type: type,
    delimiters: delimiters,
    wontache: wontache
  }, {
    partials: partials
  });
};

var wrapModule$1 = wrapModule;

module.exports = wrapModule$1;
//# sourceMappingURL=wrap-module.js.map
